import typer
import uvicorn

from popug_sdk.conf import settings


def runserver(
        host: str = typer.Option("0.0.0.0"),
        port: int = typer.Option(settings.app.app_port),
        debug: bool = typer.Option(False),
        reload: bool = typer.Option(False),
        workers: int = typer.Option(1)
):
    uvicorn.run(
        settings.app.instance, host=host, port=port,
        debug=debug, reload=reload, workers=workers
    )



from typing import Any

from sqlalchemy.ext.declarative import (
    as_declarative,
    declared_attr,
)

__all__ = (
    "BaseModel",
)


@as_declarative()
class BaseModel:
    id: Any
    __name__: str

    @declared_attr
    def __tablename__(cls) -> str:
        return cls.__name__.lower()

    def __init__(self, *args, **kwargs):  # pragma: no cover
        super().__init__(*args, **kwargs)
